@@ -12,7 +12,7 @@ BEGIN {
 
 BEGIN {
 	$Types::Standard::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Standard::VERSION   = '1.012003';
+	$Types::Standard::VERSION   = '1.012005';
 }
 
 $Types::Standard::VERSION =~ tr/_//d;
@@ -1511,7 +1511,7 @@ Here's an example using L<Regexp::Common>:
       has ip_address => (
          is         => 'ro',
          required   => 1,
-         isa        => StrMatch[/^$RE{net}{IPv4}$/],
+         isa        => StrMatch[qr/^$RE{net}{IPv4}$/],
          default    => '127.0.0.1',
       );
    }
